@@ -86,6 +86,8 @@ def main(argv):
     
     global branch
     global commit_message
+    
+    debug = 0
    
     try:
         opts, args = getopt.getopt(argv, "a:b:c:d:h:f:m:n:u:p:r:g:t:w:", ["command=", "help", 
@@ -145,7 +147,7 @@ def main(argv):
                 print("Or")
                 print("python -m artify --command deltav --type <version_change> --archtype <architecture_type>")
                 print("")
-                print("e.g --archtype npm, dotnet, springboot ")
+                print("e.g --archtype npm, gradle, maven, dotnet, netcore")
                 print("\nOptional arguments: ")
                 print("-b, --branch        Branch to commit code changes. Default: develop")
                 print("e.g --type major    1.0.0.0 => 2.0.0.0")
@@ -289,7 +291,7 @@ def main(argv):
     if action == 'deltav':
         change_version.modify_version()
     if action == 'syncrepo':
-        syncrepo.commit_push_changes()
+        syncrepo.commit_push_changes(commit_message)
     if action == 'deploy':
         deploy.deploy_app_awx()
     
