@@ -1,10 +1,10 @@
 import __main__
 import re
 
-def commit_push_changes():
+def commit_push_changes(message):
     print("Committing changes:::")
     path = __main__.os.path.abspath(__main__.os.getcwd())   
-    git_commit_command = "git commit -am '{}'".format(commit_message)
+    git_commit_command = "git commit -am '{}'".format(message)
     process_git_commit = __main__.Popen(git_commit_command, shell=True, stdout=__main__.PIPE, cwd=path)
     print("Commit result: ", process_git_commit.communicate()[0])
         
